# Generated by Django 2.1.1 on 2019-03-25 10:34

from django.db import migrations
import django.db.models.deletion
import djangoplus.db.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('documentos', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='certidao',
            name='cartorio',
            field=djangoplus.db.models.fields.CharField(blank=True, max_length=255, null=True, verbose_name='Cartório'),
        ),
        migrations.AlterField(
            model_name='certidao',
            name='data',
            field=djangoplus.db.models.fields.DateField(blank=True, null=True, verbose_name='Data'),
        ),
        migrations.AlterField(
            model_name='certidao',
            name='folha',
            field=djangoplus.db.models.fields.CharField(blank=True, max_length=255, null=True, verbose_name='Folha'),
        ),
        migrations.AlterField(
            model_name='certidao',
            name='livro',
            field=djangoplus.db.models.fields.CharField(blank=True, max_length=255, null=True, verbose_name='Livro'),
        ),
        migrations.AlterField(
            model_name='certidao',
            name='municipio',
            field=djangoplus.db.models.fields.ForeignKey(null=True, blank=True, on_delete=django.db.models.deletion.CASCADE, to='enderecos.Municipio', verbose_name='Município'),
        ),
        migrations.AlterField(
            model_name='certidao',
            name='tipo',
            field=djangoplus.db.models.fields.CharField(choices=[['Nascimento', 'Nascimento'], ['Casamento', 'Casamento'], ['Novo Modelo', 'Novo Modelo']], max_length=255, verbose_name='Tipo'),
        ),
    ]



# Generated by Django 2.1.7 on 2019-03-20 15:39

from django.db import migrations, models
import django.db.models.deletion
import djangoplus.db.models.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('enderecos', '0001_squashed_0006_auto_20170605_2058'),
    ]

    operations = [
        migrations.CreateModel(
            name='Certidao',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tipo', djangoplus.db.models.fields.CharField(choices=[['Nascimento', 'Nascimento'], ['Casamento', 'Casamento']], max_length=255, verbose_name='Tipo')),
                ('numero', djangoplus.db.models.fields.CharField(max_length=255, verbose_name='Número')),
                ('cartorio', djangoplus.db.models.fields.CharField(max_length=255, verbose_name='Cartório')),
                ('livro', djangoplus.db.models.fields.CharField(max_length=255, verbose_name='Livro')),
                ('folha', djangoplus.db.models.fields.CharField(max_length=255, verbose_name='Folha')),
                ('data', djangoplus.db.models.fields.DateField(verbose_name='Data')),
                ('municipio', djangoplus.db.models.fields.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='enderecos.Municipio', verbose_name='Município')),
            ],
            options={
                'verbose_name': 'Certidão',
                'verbose_name_plural': 'Certidões',
            },
        ),
        migrations.CreateModel(
            name='CertificadoMilitar',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('numero', djangoplus.db.models.fields.CharField(max_length=255, verbose_name='Número')),
                ('serie', djangoplus.db.models.fields.CharField(max_length=255, verbose_name='Série')),
                ('categoria', djangoplus.db.models.fields.CharField(blank=True, max_length=255, null=True, verbose_name='Categoria')),
            ],
            options={
                'verbose_name': 'Certificado Militar',
                'verbose_name_plural': 'Certificado Militars',
            },
        ),
        migrations.CreateModel(
            name='RG',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('numero', djangoplus.db.models.fields.CharField(max_length=255, verbose_name='Número')),
                ('data', djangoplus.db.models.fields.DateField(verbose_name='Data de Expedição')),
                ('orgao', djangoplus.db.models.fields.CharField(max_length=255, verbose_name='Orgão Expedidor')),
                ('uf', djangoplus.db.models.fields.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='enderecos.Estado', verbose_name='UF')),
            ],
            options={
                'verbose_name': 'RG',
                'verbose_name_plural': 'RGs',
            },
        ),
        migrations.CreateModel(
            name='TituloEleitor',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('numero', djangoplus.db.models.fields.IntegerField(verbose_name='Número')),
                ('zona', djangoplus.db.models.fields.CharField(max_length=255, verbose_name='Zona')),
                ('secao', djangoplus.db.models.fields.CharField(max_length=255, verbose_name='Seção')),
                ('municipio', djangoplus.db.models.fields.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='enderecos.Municipio', verbose_name='Município')),
            ],
            options={
                'verbose_name': 'Título de Eleitor',
                'verbose_name_plural': 'Títulos de Eleitores',
            },
        ),
    ]



# -*- coding: utf-8 -*-

from djangoplus.db import models
from django.core.exceptions import ValidationError
from enderecos.models import Municipio, Estado


class Certidao(models.Model):
    tipo = models.CharField(verbose_name='Tipo', choices=[[x, x] for x in ['Nascimento', 'Casamento', 'Novo Modelo']])
    numero = models.CharField(verbose_name='Número')
    cartorio = models.CharField(verbose_name='Cartório', null=True, blank=True)
    livro = models.CharField(verbose_name='Livro', null=True, blank=True)
    folha = models.CharField(verbose_name='Folha', null=True, blank=True)
    data = models.DateField(verbose_name='Data', null=True, blank=True)
    municipio = models.ForeignKey(Municipio, verbose_name='Município', lazy=True, null=True, blank=True)

    fieldsets = (
        ('Dados Gerais', {'fields': (('tipo', 'numero'), 'cartorio', ('livro', 'folha'), ('data', 'municipio'))}),
    )

    class Meta:
        verbose_name = 'Certidão'
        verbose_name_plural = 'Certidões'

    def __str__(self):
        return self.numero

    def save(self, *args, **kwargs):
        if self.tipo != 'Novo Modelo':
            if not (self.cartorio and self.livro and self.folha and self.data and self.municipio):
                raise ValidationError('Os demais campos são obrigatórios para certidões do modelo antigo.')
        super().save(*args, **kwargs)



class RG(models.Model):
    numero = models.CharField(verbose_name='Número')
    data = models.DateField(verbose_name='Data de Expedição')
    orgao = models.CharField(verbose_name='Orgão Expedidor')
    uf = models.ForeignKey(Estado, verbose_name='UF')

    fieldsets = (
        ('Dados Gerais', {'fields': (('numero', 'data'), ('orgao', 'uf'))}),
    )

    class Meta:
        verbose_name = 'RG'
        verbose_name_plural = 'RGs'

    def __str__(self):
        return self.numero


class CertificadoMilitar(models.Model):
    numero = models.CharField(verbose_name='Número')
    serie = models.CharField(verbose_name='Série')
    categoria = models.CharField(verbose_name='Categoria', null=True, blank=True)

    fieldsets = (
        ('Dados Gerais', {'fields': (('numero', 'serie', 'categoria'),)}),
    )

    class Meta:
        verbose_name = 'Certificado Militar'
        verbose_name_plural = 'Certificado Militars'

    def __str__(self):
        return self.numero


class TituloEleitor(models.Model):

    numero = models.IntegerField(verbose_name='Número')
    zona = models.CharField(verbose_name='Zona')
    secao = models.CharField(verbose_name='Seção')
    municipio = models.ForeignKey(Municipio, verbose_name='Município', lazy=True)

    fieldsets = (
        ('Dados Gerais', {'fields': (('numero', 'zona'), ('secao', 'municipio'))}),
    )

    class Meta:
        verbose_name = 'Título de Eleitor'
        verbose_name_plural = 'Títulos de Eleitores'

    def __str__(self):
        return self.numero
